@@ -1,4 +1,6 @@
-from librelingo_utils import get_dumb_opaque_id, audio_id, clean_word
+import editdistance
+
+from librelingo_utils import get_dumb_opaque_id, audio_id, clean_word, iterate_phrases
 from .dictionary import _define_words_in_sentence
 
 
@@ -56,10 +58,42 @@ def get_options_challenge(phrase, _):
     }]
 
 
-def get_chips(phrase):
+def get_chips_from_string(phrase):
     return list(map(clean_word, phrase.split()))
 
 
+def get_chips_from_phrase(get_input_texts, phrase, course):
+    extra_chips = []
+    solution_chips = get_chips_from_string(get_input_texts(phrase)[0])
+
+    for phrase in iterate_phrases(course):
+        for variant in get_input_texts(phrase):
+            for chip in get_chips_from_string(variant):
+                if chip not in solution_chips:
+                    extra_chips.append(chip)
+
+    chips_already_added = set()
+    deduplicated_chips = []
+
+    for chip in extra_chips:
+        if chip.lower() not in chips_already_added:
+            deduplicated_chips.append(chip)
+            chips_already_added.add(chip.lower())
+
+    extra_chips = sorted(
+        deduplicated_chips,
+        key=lambda chip: sum(
+            editdistance.eval(other_chip, chip) for other_chip in solution_chips
+        )
+    )
+
+    return solution_chips + extra_chips[0:max(len(solution_chips) - 1, 2)]
+
+
+def get_solutions_from_phrase(get_input_texts, phrase):
+    return [get_chips_from_string(x) for x in get_input_texts(phrase)]
+
+
 def create_chips_challenge_generator(reverse):
     def get_input_texts(phrase):
         return phrase.in_source_language if reverse else phrase.in_target_language
@@ -88,8 +122,8 @@ def create_chips_challenge_generator(reverse):
             "type": "chips",
             "translatesToSourceLanguage": reverse,
             "phrase": _define_words_in_sentence(course, get_phrase_text(phrase), reverse),
-            "chips": get_chips(get_input_text(phrase)),
-            "solutions": [get_chips(x) for x in get_input_texts(phrase)],
+            "chips": get_chips_from_phrase(get_input_texts, phrase, course),
+            "solutions": get_solutions_from_phrase(get_input_texts, phrase),
             "formattedSolution": get_input_text(phrase),
             "id": get_dumb_opaque_id("Chips", phrase, "reverse chips" if reverse else "chips"),
             "priority": 2,
